
/**
 * Represents an animating image in the game canvas
 * 
 * @author JP Vergara 
 * @version 29 April 2013
 */

import java.awt.image.BufferedImage;
import java.io.*;
import javax.imageio.ImageIO;

public class Sprite
{
   protected String imageFileName;
   protected String name;
   protected int x;
   protected int y;
   protected int width;
   protected int height;
   protected int deltaX;
   protected int deltaY;
   protected GameCanvas context;
   protected BufferedImage buff;
   protected boolean active;

   public Sprite( String fn, String name, int x, int y, int width, int height,
                  int dX, int dY, GameCanvas context )
   {
      this.imageFileName = fn;
      this.name = name;
      this.x = x;
      this.y = y;
      this.width = width;
      this.height = height;
      this.active = true;
      this.deltaX = dX;
      this.deltaY = dY;
      this.context = context;
      setImageFileName(fn);
   }

   public void setImageFileName(String fn)
   {
      try
      {
         this.buff = ImageIO.read(new FileInputStream(fn));
      }
      catch(IOException e)
      {
          System.out.println("image file missing");
	  }
   }

   public void setActive( boolean active )
   {
      this.active = active;
   }

   public boolean isActive()
   {
      return active;
   }

   public void deactivationTimer( final long millis )
   {
      Thread t = new Thread()
      {
         public void run()
         {
            try {Thread.sleep(millis);} catch(Exception e) {}
            active = false;
         }
      };
      t.start();
   }

   public int getX()
   {
      return x;
   }

   public int getY()
   {
      return y;
   }

   public int getWidth()
   {
      return width;
   }

   public int getHeight()
   {
      return height;
   }

   public String getName()
   {
      return name;
   }

   public String getImageFileName()
   {
      return imageFileName;
   }

   public BufferedImage getImage()
   {
      return buff;
   }

   public void setRate(int dX, int dY)
   {
      deltaX = dX;
      deltaY = dY;
   }

   public void move()
   {
      int maxX = context.getWidth();
      int maxY = context.getHeight();
      x =  (x + deltaX + maxX) % maxX;
      y =  (y + deltaY + maxY) % maxY;
   }

   public boolean collidesWith( Sprite other )
   {
      int l1 = getX();
      int r1 = getX()+getWidth();
      int l2 = other.getX();
      int r2 = other.getX()+other.getWidth();
      int t1 = getY();
      int b1 = getY()+getHeight();
      int t2 = other.getY();
      int b2 = other.getY()+other.getHeight();
      if ((l1 < r2) && (r1 > l2))
      if ((t1 < b2) && (b1 > t2))
         return true;
      return false;
   }

   public void collided( Sprite other )
   {
      System.out.println("collision!");
   }
}
